The mappings are as follows:

legacy_app_name  | normalized_os | app_name         | product          | canonical_app_name              | 2019  | 2020  | 2021
---------------- | ------------- | ---------------- | ---------------- | ------------------------------- | ----- | ----  | ----
Firefox          | *             | firefox_desktop  | Firefox          | Firefox for Desktop             | true  | true  | true
Fenix            | Android       | fenix            | Fenix            | Firefox for Android (Fenix)     | true  | true  | true
Fennec           | Android       | fennec           | Fennec           | Firefox for Android (Fennec)    | true  | true  | true
Firefox Preview  | Android       | firefox_preview  | Firefox Preview  | Firefox Preview for Android     | true  | true  | true
Fennec           | iOS           | firefox_ios      | Firefox iOS      | Firefox for iOS                 | true  | true  | true
FirefoxForFireTV | Android       | firefox_fire_tv  | Firefox Fire TV  | Firefox for Fire TV             | false | false | false
FirefoxConnect   | Android       | firefox_connect  | Firefox Echo     | Firefox for Echo Show           | true  | true  | false
Zerda            | Android       | firefox_lite     | Firefox Lite     | Firefox Lite                    | true  | true  | false
Zerda_cn         | Android       | firefox_lite_cn  | Firefox Lite CN  | Firefox Lite (China)            | false | false | false
Focus            | Android       | focus_android    | Focus Android    | Firefox Focus for Android       | true  | true  | true
Focus            | iOS           | focus_ios        | Focus iOS        | Firefox Focus for iOS           | true  | true  | true
Klar             | Android       | klar_android     | Klar Android     | Firefox Klar for Android        | false | false | false
Klar             | iOS           | klar_ios         | Klar iOS         | Firefox Klar for iOS            | false | false | false
Lockbox          | Android       | lockwise_android | Lockwise Android | Lockwise for Android            | true  | true  | false
Lockbox          | iOS           | lockwise_ios     | Lockwise iOS     | Lockwise for iOS                | true  | true  | false
FirefoxReality*  | Android       | firefox_reality  | Firefox Reality  | Firefox Reality                 | false | false | false
